<?php

namespace Drupal\synimport\Drush;

use Drush\Commands\DrushCommands;
use Drupal\synimport\Service\ImportInterface;

/**
 * A Drush commandfile.
 */
class DrushContentImport extends DrushCommands {

  /**
   * Service for service.
   *
   * @var Drupal\synimport\Service\Import
   */
  protected $synimport;

  /**
   * Command constructor.
   */
  public function __construct(ImportInterface $synimport) {
    $this->synimport = $synimport;
  }

  /**
   * Synapse Content import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport
   *   Full import from $directory.
   */
  public function import($directory) {
    $this->output()->writeln("Import Content from: $directory");
    $this->synimport->setLogger($this->logger());
    $this->synimport->import($directory);
    $this->output()->writeln("!NOTE Done.");
  }

  /**
   * Synapse Contacts import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:contacts
   *   Contacts import from $directory/contacts.
   */
  public function importContacts($directory) {
    $this->output()->writeln("Import Contacts from: $directory/contacts");
    $this->synimport->importContacts($directory);
    $this->output()->writeln("!NOTE Done.");
  }

  /**
   * Synapse Taxonomy import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:taxonomy
   *   Taxonomy import from $directory/taxonomy.
   */
  public function importTaxonomy($directory) {
    $this->output()->writeln("Import Taxonomy from: $directory/taxonomy");
    $this->synimport->setLogger($this->logger());
    $this->synimport->importTaxonomy($directory);
    $this->output()->writeln("!NOTE Done.");
  }

  /**
   * Synapse Nodes import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:node
   *   Nodes import from $directory/nodes.
   */
  public function importNode($directory) {
    $this->output()->writeln("Import Nodes from: $directory/nodes");
    $this->synimport->setLogger($this->logger());
    $this->synimport->importNode($directory);
    $this->output()->writeln("!NOTE Done.");
  }

  /**
   * Synapse Menu import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:menu
   *   Menu import from $directory/menu.
   */
  public function importMenu($directory) {
    $this->output()->writeln("Import Menu from: $directory/menu");
    $this->synimport->importMenu($directory);
    $this->output()->writeln("!NOTE Done.");
  }

  /**
   * Synapse Products import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:product
   *   Products import from $directory/products.
   */
  public function importProducts($directory) {
    $this->output()->writeln("Import Products from: $directory/products");
    $this->synimport->setLogger($this->logger());
    $this->synimport->importProducts($directory);
    $this->output()->writeln("!NOTE Done.");
  }

  /**
   * Synapse Blocks import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:block
   *   Blocks import from $directory/block.
   */
  public function importBlocks($directory) {
    $this->output()->writeln("Import Blocks from: $directory/block");
    $this->synimport->importBlocks($directory);
    $this->output()->writeln("!NOTE Done.");
  }

  /**
   * Synapse Synlanding Config import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:synlanding_config
   *   Synlanding Config import from $directory/synlanding.
   */
  public function setSynlandingFormBg($directory) {
    $this->output()->writeln("Import SynLandingConfig from: $directory/synlanding");
    $this->synimport->setSynlandingFormBg($directory);
    $this->output()->writeln("!NOTE Done.");
  }

}
